@@ -3,7 +3,15 @@
 .onLoad <- function(libname, pkgname) {
   debug <- isTRUE(as.logical(Sys.getenv("R_FUTURE_TESTS_DEBUG", FALSE)))
   options(future.tests.debug = debug)
-  
+
+  value <- getOption("future.tests.undo")
+  if (is.null(value)) {
+    value <- Sys.getenv("R_FUTURE_TESTS_UNDO", "envvars,graphics,objects,options,rng")
+    value <- unlist(strsplit(value, split = ","))
+    value <- gsub(" ", "", value)
+    options(future.tests.undo = value)
+  }
+
   args <- parseCmdArgs()
   cores <- args$cores
   if (is.null(cores)) {
